@@ -10,5 +10,7 @@ def get_tree(argv):
     stream = CommonTokenStream(lexer)
     parser = UVLParser(stream)
     tree = parser.feature_model()
+    print(tree.toStringTree(tree, parser))
     return tree
 
+get_tree("test.uvl")
\ No newline at end of file
